@@ -37,35 +37,40 @@ test_that("ec.init presets for non-grouped data.frame", {
 
 test_that("ec.init presets for grouped data.frame", {
   p <- df |> dplyr::group_by(symbol) |> ec.init(yAxis= list(scale=TRUE, name='yaxe'))
-  expect_equal(p$x$opts$xAxis$type, 'category')
-  expect_equal(p$x$opts$yAxis$name, 'yaxe')
-  expect_equal(length(p$x$opts$dataset[[1]]$source), 11)
-  expect_equal(length(p$x$opts$legend$data), 3)
-  expect_equal(p$x$opts$series[[1]]$type, 'scatter')
-  expect_equal(p$x$opts$series[[1]]$datasetIndex, 1)
-  expect_equal(p$x$opts$series[[1]]$name, 'circle')
+  po <- p$x$opts
+  expect_equal(po$xAxis$type, 'category')
+  expect_equal(po$yAxis$name, 'yaxe')
+  expect_equal(length(po$dataset[[1]]$source), 11)
+  expect_equal(length(po$legend$data), 3)
+  expect_equal(po$series[[1]]$type, 'scatter')
+  expect_equal(po$series[[1]]$name, 'circle')
+  expect_equal(po$series[[2]]$datasetIndex, 2)
 })
 
 test_that("ec.init presets for timeline", {
+  # TODO 'timeline= list(data=,axisType=)'...
   dftl <- data.frame(
-    year = unlist(lapply(2018:2021, function(x) {rep(x, 4)})), 
+    value = runif(16),
     quarter = as.factor(rep(1:4, 4)),
-    value = runif(16)
+    year = unlist(lapply(2018:2021, function(x) {rep(x, 4)}))
   )
-  barTL <- function(data, timeline_var, x_var, bar_var) {
+  barTL <- function(data, timeline_var) {  #}, x_var, bar_var) {
     bt <- data |> dplyr::group_by(!!dplyr::sym(timeline_var)) |> 
-      ec.init(tl.series = list(type='bar', encode=list(x=x_var, y=bar_var)),
-              xAxis= list(name='xval'))
+      ec.init(series.param = list(type='bar'), #,encode=list(x=x_var, y=bar_var)),
+              xAxis= list(name='xval'),
+              timeline= list(s=T) # data= c(1,2,3,4), axisType='value') #ok
+      )
     bt
   }
-  p <- barTL(dftl, timeline_var= "year", x_var= "value", bar_var= "quarter")
+  p <- barTL(dftl, timeline_var= "year") #, x_var= "value", bar_var= "quarter")
   o <- p$x$opts
   expect_equal(length(o$dataset[[1]]$source), 17)
   expect_equal(length(o$dataset), 5)
   expect_equal(length(o$options), 4)
-  expect_equal(o$options[[4]]$title$text, '2021')
+  expect_equal(o$timeline$axisType, 'category')
   expect_equal(o$yAxis$name, 'quarter')
   expect_equal(o$xAxis$name, 'xval')
+  expect_equal(o$options[[1]]$series[[1]]$encode, list(x=0, y=1, z=2))
 })
 
 test_that("ec.init presets for timeline groupBy", {
@@ -73,23 +78,61 @@ test_that("ec.init presets for timeline groupBy", {
   dat <- data.frame(
     x1 = rep(2020:2023, each = 4),
     x2 = rep(c("A", "A", "B", "B"), 4),
-    x3 = runif(16),
+    x = runif(16),
     x4 = runif(16),
-    x5 = abs(runif(16))
+    y = abs(runif(16)), z= runif(16)
   ) 
   p <- dat |> group_by(x1) |> ec.init(
-    tl.series= list(encode= list(x= 'x3', y= 'x5'), 
-                    symbolSize= ec.clmn(2, scale=30),
+    legend= list(show=TRUE),
+    tl.series= list(encode= list(x= 'x', y= 'y'), 
+                    symbolSize= ec.clmn('x4', scale=30),
                     groupBy= 'x2') 
   )
-  p$x$opts$legend <- list(show=TRUE)
   expect_equal(p$x$opts$options[[4]]$series[[1]]$type, 'scatter')
-  expect_equal(p$x$opts$options[[4]]$series[[1]]$encode$y, 'x5')
-  expect_equal(p$x$opts$yAxis$name, 'x5')
+  expect_equal(p$x$opts$options[[4]]$series[[1]]$encode$y, 'y')
+  expect_equal(p$x$opts$yAxis$name, 'y')
+
+  p <- dat |> group_by(x1) |> ec.init(#load='3D',
+    xAxis3D=list(s=T),yAxis3D=list(s=T),zAxis3D=list(s=T),grid3D=list(s=T),
+    timeline=list(s=T), legend= list(show=TRUE), 
+    series.param= list(type='scatter3D', groupBy= 'x2',
+      encode= list(x='x', y='y', z='z'), 
+      symbolSize= ec.clmn('x4', scale=30) )
+  )
+  expect_equal(p$x$opts$options[[1]]$series[[1]]$coordinateSystem, 'cartesian3D')
+  expect_equal(length(p$x$opts$options[[1]]$series), 2)
+  expect_equal(p$x$opts$options[[4]]$series[[2]]$datasetIndex, 8)
+  expect_equal(p$x$opts$options[[4]]$series[[2]]$name, 'B')
+  
+  cns <- data.frame(
+    val = c(22, 99, 33),
+    dim = c(11, 88, 44),
+    nam = c('Brazil','China','India')
+  )
+  p <- cns |> group_by(nam) |> 
+  ec.init(load= 'world', tooltip= list(show=T),
+    tl.series= list(type='map', encode= list(name='nam', value='val')), 
+    visualMap= list(calculable=TRUE, dimension=2)
+  )
+  # name & value are required column names for tl.series
+  expect_equal(p$x$opts$options[[3]]$series[[1]]$geoIndex,0)  # decremented
+  #expect_equal(p$x$opts$options[[1]]$series[[1]]$data[[1]]$name, 'Brazil')
+  expect_equal(p$x$opts$options[[1]]$series[[1]]$datasetIndex, 1)
+  expect_equal(p$x$opts$geo$map, 'world')
+  expect_equal(p$x$opts$visualMap$max, 88)
+  
+  p <- cns |> relocate(dim, .after = last_col()) |>
+    ec.init(load= 'world', series.param= list(type='map'), visualMap= list(s=T))
+  # defaults:
+  # 1. map series will pick up the first num column for values, first char col for name
+  # 2. visualMap will pick up the last column for max/min
+  expect_equal(p$x$opts$dataset[[1]]$source[[1]], c("val","nam","dim"))
+  expect_equal(p$x$opts$series[[1]]$geoIndex, 0)
+  expect_equal(p$x$opts$visualMap$max, 88)
 })
 
 test_that("presets for parallel chart", {
-  p <- mtcars |> group_by(cyl) |> ec.init(ctype='parallel')
+  p <- mtcars |> relocate(cyl, .after=last_col()) |> group_by(cyl) |> ec.init(ctype='parallel')
 
   expect_equal(length(p$x$opts$dataset), 4)
   expect_equal(p$x$opts$series[[3]]$datasetIndex, 3)
@@ -188,10 +231,45 @@ test_that('axis names from preset encode', {
   expect_equal(p$x$opts$xAxis$name, 'dist')
 })
 
-test_that('polar, pie, world', {
+test_that('polar, pie, radar, themeRiver, parallel, etc.', {
   p <- cars |> ec.init(ctype='pie')
   expect_equal(p$x$opts$dataset[[1]]$source[[1]][1], 'speed')
   p <- cars |> ec.init(polar= list(radius= 222), 
       series.param= list(type='line', smooth=T))
   expect_equal(p$x$opts$series[[1]]$coordinateSystem, 'polar')
+  dd <- data.frame(
+    c1 = rep(1:3, each= 2),
+    c2 = c(0,1,2,3,2,1),
+    c3 = rep(c('d1', 'd2'), 3)
+  )
+  p <- ec.init(series.param= list(
+    type='themeRiver', data= ec.data(dd), label= list(s=T) ) )
+  expect_equal(p$x$opts$singleAxis, list(min='dataMin', max='dataMax'))
+  
+  p <- ec.init(
+  	radar= list(indicator= lapply(LETTERS[1:5], \(x){list(name= x)}) ),
+  	series.param= list(type='radar', data= list(list(name='r1', value= runif(5, 1, 5))) )
+  )
+  expect_equal(p$x$opts$series[[1]]$type, 'radar')
+  
+    # group column to be last
+  p <- mtcars |> relocate(cyl, .after= last_col()) |> group_by(cyl) |> 
+    ec.init(ctype='parallel')
+  expect_equal(length(p$x$opts$series), 3)
+  expect_equal(length(p$x$opts$parallelAxis), 10)
+  expect_equal(p$x$opts$parallelAxis[[1]]$name, 'mpg')
+  
+  p <- ec.init(series.param= list(
+    type='gauge', data= list(list(name='score',value=44))))
+  expect_equal(names(p$x$opts), 'series')
+})
+
+test_that('polar presets', {
+  df <- data.frame(x = 1:10, y = seq(1, 20, by = 2))
+  p <- df |> ec.init(ctype='line', polar= list(dummy= T), 
+  		 series.param= list(smooth= T)
+  )
+  expect_equal(p$x$opts$polar$radius, 111)
+  expect_equal(p$x$opts$radiusAxis$type, 'category')
+  expect_equal(p$x$opts$series[[1]]$coordinateSystem, 'polar')
 })
